==> haskell-silently-1.2.5-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-silently.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: silently
version: 1.2.5
id: silently-1.2.5-4d48ibUelDmLXErYHoAYYi
key: silently-1.2.5-4d48ibUelDmLXErYHoAYYi
license: BSD3
copyright: (c) Trystan Spangler 2011
maintainer: Sönke Hahn <soenkehahn@gmail.com>, Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/silently
package-url: https://github.com/hspec/silently
synopsis: Prevent or capture writing to stdout and other handles.
description:
    Prevent or capture writing to stdout and other handles.
category: System, Testing
author: Trystan Spangler
exposed: True
indefinite: False
exposed-modules:
    System.IO.Silently
abi: a850c1d1858a4c2180c92a1c52b9655c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/silently-1.2.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/silently-1.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/silently-1.2.5
hs-libraries: HSsilently-1.2.5-4d48ibUelDmLXErYHoAYYi
depends:
    base-4.10.0.0 directory-1.3.0.2 deepseq-1.4.3.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
haddock-interfaces: /usr/share/doc/haskell-silently/html/silently.haddock
haddock-html: /usr/share/doc/haskell-silently/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-silently-1.2.5-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-silently.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: silently
version: 1.2.5
id: silently-1.2.5-A7WEXUoXcTh1TcbS3dokt3
key: silently-1.2.5-A7WEXUoXcTh1TcbS3dokt3
license: BSD3
copyright: (c) Trystan Spangler 2011
maintainer: Sönke Hahn <soenkehahn@gmail.com>, Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/silently
package-url: https://github.com/hspec/silently
synopsis: Prevent or capture writing to stdout and other handles.
description:
    Prevent or capture writing to stdout and other handles.
category: System, Testing
author: Trystan Spangler
exposed: True
indefinite: False
exposed-modules:
    System.IO.Silently
abi: d2dd9be64414e7e060e4b54fbebd65e8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/silently-1.2.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/silently-1.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/silently-1.2.5
hs-libraries: HSsilently-1.2.5-A7WEXUoXcTh1TcbS3dokt3
depends:
    base-4.10.1.0 directory-1.3.0.2 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-silently/html/silently.haddock
haddock-html: /usr/share/doc/haskell-silently/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
